
# command-router [![Build Status](https://travis-ci.org/jxson/command-router.png?branch=master)](https://travis-ci.org/jxson/command-router)

Ideally applications should be developed in a modular way that allows their functionality to be used in multiple contexts. `command-router` aims to make this easier by lowering the cognitive load around developing applications that might provide multiple actions through their CLI (like `git`).

`command-router` provides:

* A simple way to declare routing definitions using normal functions.
* A clean way to define options, their aliases, and default values
* Tab completion!

If your app only has one command (like `curl` for instance) you should use a module like [optimist][optimist] instead of this one.

# Example

Define basic CLI actions:

    var cli = require('command-router')

    // Options are optional, and basic boolean options that default to
    // false can be simply defined
    cli.option('verbose')

    // Define the --port option with an alias of -p and set an
    // intelligent default
    cli.option({ name: 'port'
    , alias: 'p'
    , default: process.env.PORT || 8080
    , type: Number
    })

    cli.command('help', function(){
      console.log('commands: server')
    })

    cli.command('server', function(){
      if (cli.options.help) {
        return console.log('Help for server the command')
      }

      // code for running server here...
    })

    // Set the whole thing in motion...
    cli.parse(process.argv)


There is a default catch all route which will exit with a error code 1 if triggered (this makes things nice for automation), you can override this behavior by adding your own default.

    cli.default = function(){
      console.log('Maybe stream some help docs here to be useful')

      process.exit(1)
    })

# Methods

    var cli = require('command-router')

## fm(string)

## Install

With [npm][npm] do:

    npm install command-router

# License

MIT

- - -

## cli.option(route, callback)

options are available to all triggered route callback, if a cb doesn't need an option i suggest you just ignore it. Remember is good to be liberal in what you acept and strict with what you return.

## cli.command(route, callback)

Define route matchers for your application using a string or regex for `route`, the `callback` function will be triggered if the `route` is matched on the `parse event`. The `callback` is not called with any arguments but is bound to the `cli` instance

### Examples

    // simple stringed route
    cli.command('speak dog', function(){
      console.log('woof.')
    })

    // name params
    cli.command('speak :animal', function(){
      console.log(this.params.animal)
    })

    // splats!
    cli.command('speak *', function(){
      console.log(this.params.splat)
    })

    // regex, don't cut your self...
    cli.command(/speak (.*)$/, function(){
      console.log(this.params.splat)
    })

## cli.parse(argv)

Parses the `argv` array and triggers the callbacks for any matching routes.

# Built on the backs of better developers

This project is really just a normalized code API which is small wrapper around several other excellent libraries:

* nopt
* routes
* tab-completer thing

= = =

use this for the test runner? https://github.com/substack/comandante



[npm]: http://npmjs.org
[optimist]: #